pyqode.python.backend package
=============================

Module contents
---------------

.. automodule:: pyqode.python.backend


Classes
-------

JediCompletionProvider
++++++++++++++++++++++

.. autoclass:: pyqode.python.backend.JediCompletionProvider
    :members:
    :undoc-members:
    :show-inheritance:

Functions
---------

calltips
++++++++
.. autofunction:: pyqode.python.backend.calltips

defined_names
+++++++++++++
.. autofunction:: pyqode.python.backend.defined_names

goto_assignments
++++++++++++++++
.. autofunction:: pyqode.python.backend.goto_assignments

icon_from_typename
++++++++++++++++++
.. autofunction:: pyqode.python.backend.icon_from_typename

quick_doc
+++++++++
.. autofunction:: pyqode.python.backend.quick_doc

run_frosted
+++++++++++
.. autofunction:: pyqode.python.backend.run_frosted

run_pep8
++++++++
.. autofunction:: pyqode.python.backend.run_pep8


Server script
-------------

.. automodule:: pyqode.python.backend.server
    :members:
    :undoc-members:
    :show-inheritance:


.. literalinclude:: /../../pyqode/python/backend/server.py
   :linenos:
